<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de_DE">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation>Letzte Prüfung:</translation>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation>Wenn Sie das Beta-Programm verlassen, erhalten Sie keine weiteren Beta-Aktualsierungen mehr</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Verlassen</translation>
    </message>
</context>
<context>
    <name>UpdateControl</name>
    <message>
        <source>View Update Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Update History</source>
        <translation>Aktualisierungs-Chronik</translation>
    </message>
    <message>
        <source>No update history</source>
        <translation>Keine Aktualisierungs-Chronik</translation>
    </message>
    <message>
        <source>System Updates</source>
        <translation>System-Aktualisierungen</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Sicherheits-Aktualisierungen</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
        <translation>Liefert eine kumulative Aktualisierung mit neuen Möglichkeiten, Qualitäts- und Sicherheitsverbesserungen</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Liefert Sicherheits-Aktualisierungen</translation>
    </message>
    <message>
        <source>Installation date:</source>
        <translation>Installationsdatum:</translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>Details anzeigen</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>Veröffentlichungsdatum:</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Einfahren</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogDialog</name>
    <message>
        <source>Update Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export to desktop</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation>NICHTS</translation>
    </message>
    <message>
        <source>LOW</source>
        <translation>GERING</translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation>MITTEL</translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation>HOCH</translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation>KRITISCH</translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation>kritisches-risiko</translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation>hohes-risiko</translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation>mittleres-risiko</translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation>niedriges-risiko</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>unbekannt</translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation>Diese Aktualisierung behebt</translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation>Sicherheitsrisiken</translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation>Sicherheitsrisiko</translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation>%1 von %2 %3</translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation>, </translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation>für weitere Einzelheiten besuchen Sie bitte</translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>Aktualisierungen werden gesucht, einen Moment bitte…</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>Ihr System ist auf dem neuesten Stand</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Unbekannter Fehler</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation>Aktualisierungen konnten nicht heruntergeladen werden. Bitte machen Sie zuerst %1 Speicherplatz frei.</translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation>Abhängigkeiten-Fehler, Aktualisierungen konnten nicht erkannt werden.</translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation>Bitte prüfen Sie Ihr Netzwerk und versuchen es erneut.</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation>Aktualisierungen konnten nicht heruntergeladen werden. Bitte  überprüfen Sie Ihr Netzwerk und versuchen es erneut.</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>System-Sicherung konnte nicht durchgeführt werden. Falls Sie mit den System-Aktualisierungen fortfahren, können Sie nicht wieder zurück zum alten System.</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Falls Sie mit den Aktualisierungen fortfahren, können Sie nicht wieder zurück zum alten System.</translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation>Zu wenig Speicherplatz</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKG-Fehler</translation>
    </message>
    <message>
        <source>File missing</source>
        <translation>Datei fehlt</translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation>Service-Verbindung ist unnormal, bitte prüfen Sie das Netzwerk und versuchen es erneut</translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation>Diese Repositorien-Quellen-Konfiguration ist ungültig, bitte überprüfen Sie dies und versuchen es erneut.</translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation>Nochmals prüfen</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation>Datenschutzerklärung</translation>
    </message>
    <message>
        <source>To use this software, you must accept the %1 that accompanies software updates.</source>
        <translation>Um diese Software zu benutzen, müssen die %1 akzeptieren, die den Software-Aktualisieren beigefügt ist.</translation>
    </message>
    <message>
        <source>Turn on the switches under Update Content to get better experiences</source>
        <translation>Schalten Sie die Schalter bei Inhalt aktualisieren ein für bessere Ergebnisse</translation>
    </message>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation>Ihr System ist nicht aktiviert, und konnte sich nicht mit den Aktualisierungsdiensten verbinden</translation>
    </message>
    <message>
        <source>The system updates are disabled. Please contact your administrator for help</source>
        <translation>Die System-Aktualisierungen sind ausgeschaltet. Bitte kontaktieren Sie Ihren Administrator.</translation>
    </message>
    <message>
        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateSelectDialog</name>
    <message>
        <source>The updates have been already downloaded. What do you want to do?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Silent Installation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation>Smarter Spiegelserverwechsel</translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation>Aktualisierungs-Typ</translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation>Funktions-Aktualisierungen</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation>Liefert eine Aktualisierungs-Kombination aus neuen Funktionen, Verbesserungen und Sicherheitsverbesserungen</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Sicherheits-Aktualisierungen</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Liefert Sicherheits-Aktualisierungen</translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation>Drittparteien-Aktualisierungen</translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation>Liefert Aktualisierungen für zusätzliche Repositorien-Quellen</translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation>Geschwindigkeit begrenzen</translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation>Geschwindigkeitseinstellung</translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation>Automatischer Download</translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation>Das Einschalten von &quot;Aktualisierungen automatisch herunterladen&quot; wird eben dieses tun, wenn eine Internetverbindung besteht</translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation>Herunterladen, wenn inaktiv</translation>
    </message>
    <message>
        <source>Start at</source>
        <translation>Beginn um</translation>
    </message>
    <message>
        <source>End at</source>
        <translation>Ende um</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Fortgeschrittene Einstellungen</translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation>Aktualisierungs-Benachrichtigung</translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation>Paket-Cache-Speicher leeren</translation>
    </message>
    <message>
        <source>Update History</source>
        <translation>Aktualisierungs-Chronik</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation>Dem Intern-Test-Kanal beitreten</translation>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation>Klicken Sie um die das Programm abzuschließen</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Aufklappen</translation>
    </message>
    <message>
        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
        <translation>Forumsteilnehmer auf Stufe 2 und höher können dem Betatest beitreten um die neuesten Aktualisierungen zu erhalten.</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only numbers between 1-99999 are allowed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation>System-Aktualisierungen</translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation>Einige Fehler und Sicherheitsrisiken beseitigt</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Sicherheits-Aktualisierungen</translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation>Drittparteien-Repositorien</translation>
    </message>
    <message>
        <source>updatelog</source>
        <translation>Protokoll erneuern</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation>Bitte ans Stromnetz anschließen und dann Aktualisierungen installieren</translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>System-Aktualisierungen</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>System-Aktuakisierung und -Hochstufung</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>Aktualisierungs-Einstellungen</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Installieren</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation>Herunterladen abgeschlossen</translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation>Aktualisierungen einbauen</translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation>Größe der Aktualisierung:</translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation>Herunterladen der Aktualisierung fehlgeschlagen</translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation>Aktualisierungen werden heruntergeladen…</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Am Herunterladen</translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation>Aktualisierungseinstellungen, Sicherheitsaktualisierungen, Aktualisierungen automatisch Herunterladen und Aktualisierungs-Benachrichtigung</translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation>Jetzt neustarten</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Herunterladen</translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation>Aktualisierungen werden installiert…</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Erneut versuchen</translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation>Aktualisierung fortsetzen</translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation>Aktualisierungen vorhanden</translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation>Einbau der Aktualisierung fehlgeschlagen</translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation>Um das korrekte Funktionieren ihres Systems und der Programme sicherzustellen, machen Sie bitte einen Neustart nach der Aktualisierung</translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation>Datensicherung in Arbeit …</translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation>Datensicherung in Arbeit</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Datensicherung fehlgeschlagen</translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation>Einbau der Aktualisierung erfolgreich</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Falls Sie mit den Aktualisierungen fortfahren, können Sie nicht wieder zurück zum alten System.</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Nochmals probieren</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Mit der Aktualisierung fortfahren</translation>
    </message>
    <message>
        <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
        <translation>Der Akku ist unter 60%. Um die Aktualisierung erfolgreich durchführen zu können schließen Sie bitte den Rechner ans Stromnetz an.</translation>
    </message>
</context>
</TS>